/*
 * Copyright (C) 2007 LAAS/CNRS 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

typedef struct gdheTriangle {
  int vertexSize;     // size allocated for array vertex
  int vertexNumber;   // number of float in array vertex (3 for each vertex)
  int triangleSize;
  int triangleNumber; // nb of float in array triangle (3 for each triangle)
  int normalSize;
  int normalNumber;   // number of float in array normal (3 for each vertex)
  int colorSize;
  int colorNumber;    // number of byte in array color (3 for each vertex)
  GLfloat* vertex;    // array of vertex
                      // = { { x0 y0 z0 }  { x1 y1 z1 }  ... { xn yn zn} }
  GLuint* triangle;   // = { { 0 1 2 }  { 0 2 3} { 0 3 1 } { 3 2 1 } }
  GLfloat* normal;    // = { { x0 y0 z0 }  { x1 y1 z1 }  ... { xn yn zn} }
  GLubyte* color;     // = { { r0 v0 b0 }  { r1 v1 b1 }  ... { rn vn bn} }
} gdheTriangle;

extern void gdheTriangleInit(gdheTriangle* pT);
extern void gdheTriangleFree(gdheTriangle* pT);
extern void gdheTriangleFreeVertex(gdheTriangle* pT);
extern void gdheTriangleFreeTriangle(gdheTriangle* pT);
extern void gdheTriangleFreeNormal(gdheTriangle* pT);
extern void gdheTriangleFreeColor(gdheTriangle* pT);

extern void gdheTriangleDraw(gdheTriangle* triangles);

#ifdef SWIG
extern Tstatus gdheTriangleVertexResize(gdheTriangle* pT, int nbVertex);
extern Tstatus gdheTriangleNormalResize(gdheTriangle* pT, int nbNormal);
extern Tstatus gdheTriangleColorResize(gdheTriangle* pT, int nbColor);
extern Tstatus gdheTriangleTriangleResize(gdheTriangle* pT, int nbTriangle);
#else
extern int gdheTriangleVertexResize(gdheTriangle* pT, int nbVertex);
extern int gdheTriangleNormalResize(gdheTriangle* pT, int nbNormal);
extern int gdheTriangleColorResize(gdheTriangle* pT, int nbColor);
extern int gdheTriangleTriangleResize(gdheTriangle* pT, int nbTriangle);
#endif
